new_promoted_global

Function new_promoted_global 

fn new_promoted_global(
    ctx: &mut UllbcStatementTransformCtx<'_>,
    value: ConstantExpr,
    ptr_metadata: ConstantExpr,
) -> GlobalDeclRef
Add a global holding value, named like the promoted constants of the current item, and return its place. ptr_metadata is the metadata of pointers to the global.